<TS language="el_GR" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Δημιουργία νέας διεύθυνσης</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Νέo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Αντέγραψε την επιλεγμένη διεύθυνση στο πρόχειρο του συστήματος</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Αντιγραφη της επιλεγμενης διεύθυνσης στο πρόχειρο του συστηματος</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Διαγραφή</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Φράση πρόσβασης </translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Βάλτε κωδικό πρόσβασης</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>&amp;Αλλαγή κωδικού</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Επανέλαβε τον νέο κωδικό πρόσβασης</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Πορτοφόλι</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Επισκόπηση</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Εμφάνισε τη γενική εικόνα του πορτοφολιού</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Αποστολή</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Παραλαβή </translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Περιήγηση στο ιστορικό συναλλαγών</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Εξοδος από την εφαρμογή</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Επιλογές...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Εμφάνισε/Κρύψε</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Κρυπτογράφησε το πορτοφόλι</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Άλλαξε κωδικο πρόσβασης</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Αλλαγή του κωδικού κρυπτογράφησης του πορτοφολιού</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Υπογραφή &amp;Μηνύματος...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Επιβεβαίωση μηνύματος</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Παράθυρο αποσφαλμάτωσης</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Άνοιγμα κονσόλας αποσφαλμάτωσης και διαγνωστικών</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Αρχείο</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ενημερωμένο</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ενημέρωση...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Η συναλλαγή απεστάλη</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Εισερχόμενη συναλλαγή</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Το πορτοφόλι είναι &lt;b&gt;κρυπτογραφημένο&lt;/b&gt; και &lt;b&gt;κλειδωμένο&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Ποσότητα:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Ποσό:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ταρίφα</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Ταρίφα αλλαγής</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Ρέστα:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Ποσό</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Επικυρώσεις</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Επικυρωμένες</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Επεξεργασία Διεύθυνσης</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Επιγραφή</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Διεύθυνση</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Κύριο</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Δίκτυο</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Απόδοση θυρών με χρήστη &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Θύρα:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Θύρα διαμεσολαβητή</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Παράθυρο</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Εμφάνιση  μόνο εικονιδίου στην περιοχή ειδοποιήσεων κατά την ελαχιστοποίηση</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Ελαχιστοποίηση στην περιοχή ειδοποιήσεων αντί της γραμμής εργασιών</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>Ε&amp;λαχιστοποίηση κατά το κλείσιμο</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Απεικόνιση</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Γλώσσα περιβάλλοντος εργασίας: </translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Μονάδα μέτρησης:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Διαλέξτε την προεπιλεγμένη υποδιαίρεση που θα εμφανίζεται όταν στέλνετε νομίσματα.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;ΟΚ</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Ακύρωση</translation>
    </message>
    <message>
        <source>default</source>
        <translation>προεπιλογή</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Δεν είναι έγκυρη η διεύθυνση διαμεσολαβητή</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Διαθέσιμο:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Το τρέχον διαθέσιμο υπόλοιπο</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Ανώριμος</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Σύνολο:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Το τρέχον συνολικό υπόλοιπο</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Μη διαθέσιμο</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Έκδοση Πελάτη</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Πληροφορία</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Χρόνος εκκίνησης</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Αριθμός συνδέσεων</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Αλυσίδα μπλοκ</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Τρέχον αριθμός μπλοκ</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Χρόνος τελευταίου μπλοκ</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Άνοιγμα</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Εκκαθάριση</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Κονσόλα</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Κίνηση δικτύου</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Σύνολα</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Εισερχόμενα:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Εξερχόμενα:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Αρχείο καταγραφής εντοπισμού σφαλμάτων </translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Καθαρισμός κονσόλας</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Χρησιμοποιήστε το πάνω και κάτω βέλος για να περιηγηθείτε στο ιστορικο, και &lt;b&gt;Ctrl-L&lt;/b&gt; για εκκαθαριση οθονης.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Γράψτε &lt;b&gt;help&lt;/b&gt; για μια επισκόπηση των διαθέσιμων εντολών</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Αποστολή νομισμάτων</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Εισροές...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>επιλεγμένο αυτόματα</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Ανεπαρκές κεφάλαιο!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Ποσότητα:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Ποσό:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ταρίφα</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Ταρίφα αλλαγής</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Αποστολή σε πολλούς αποδέκτες ταυτόχρονα</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Προσθήκη αποδέκτη</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Καθαρισμός &amp;Όλων</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Επιβεβαίωση αποστολής</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Αποστολη</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Ποσό:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Πληρωμή &amp;σε:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Μήνυμα:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Επιγραφή</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Επικόλληση διεύθυνσης από το βιβλίο διευθύνσεων</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Υπογραφές - Είσοδος / Επαλήθευση μήνυματος </translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Υπογραφή Μηνύματος</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Επικόλληση διεύθυνσης από το βιβλίο διευθύνσεων</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Εισάγετε εδώ το μήνυμα που θέλετε να υπογράψετε</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Αντέγραφη της επιλεγμενης διεύθυνσης στο πρόχειρο του συστηματος</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Υπογραφη μήνυματος</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Επαναφορά όλων των πεδίων μήνυματος</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Καθαρισμός &amp;Όλων</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Επιβεβαίωση μηνύματος</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Επαναφορά όλων επαλήθευμενων πεδίων μήνυματος </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Αυτό το παράθυρο δείχνει μια λεπτομερή περιγραφή της συναλλαγής</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>ταλαιπωρηθειτε για να ακούσετε σε οποιαδήποτε θύρα. Χρήση - ακούστε = 0 , αν θέλετε αυτό.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Δεν είναι έγκυρη η διεύθυνση διαμεσολαβητή: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Φόρτωση διευθύνσεων...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Άγνωστo δίκτυο ορίζεται σε onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Ανεπαρκές κεφάλαιο</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Φόρτωση ευρετηρίου μπλοκ...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Φόρτωση πορτοφολιού...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Δεν μπορώ να γράψω την προεπιλεγμένη διεύθυνση</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ανίχνευση...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Η φόρτωση ολοκληρώθηκε</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
</TS>